TpmUint32

Struct TpmUint32 

pub struct TpmUint32(/* private fields */);

Implementations

Source

impl TpmUint32

pub const fn new(value: u32) -> Self

pub const fn value(self) -> u32

pub const fn get(&self) -> u32

pub const fn set(&mut self, value: u32)

pub const fn as_bytes(&self) -> &[u8; 4]

pub fn as_bytes_mut(&mut self) -> &mut [u8; 4]

pub fn to_be_bytes(self) -> [u8; 4]

pub const fn from_be_bytes(bytes: [u8; 4]) -> Self

pub fn cast(buf: &[u8]) -> TpmResult<&Self>

Casts a byte slice into a TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size. Returns TrailingData when buf is larger than this integer’s wire size.

pub fn validate(buf: &[u8]) -> TpmResult<()>

Validates an exact TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size. Returns TrailingData when buf is larger than this integer’s wire size.

pub fn validate_prefix(buf: &[u8]) -> TpmResult<()>

Validates that buf starts with a TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size.

pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>

Casts the first bytes in a slice into a TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size.

pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self

Casts a byte slice into a TPM integer wire view without validation.

Safety

The caller must ensure that buf.len() equals this integer’s wire size and that any containing protocol structure has been validated as needed.

pub fn cast_mut(buf: &mut [u8]) -> TpmResult<&mut Self>

Casts a mutable byte slice into a mutable TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size. Returns TrailingData when buf is larger than this integer’s wire size.

pub fn cast_prefix_mut(buf: &mut [u8]) -> TpmResult<(&mut Self, &mut [u8])>

Casts the first mutable bytes in a slice into a TPM integer wire view.

Errors

Returns UnexpectedEnd when buf is smaller than this integer’s wire size.

pub unsafe fn cast_mut_unchecked(buf: &mut [u8]) -> &mut Self

Casts a mutable byte slice into a mutable TPM integer wire view without validation.

Safety

The caller must ensure that buf.len() equals this integer’s wire size and that any containing protocol structure has been validated as needed. The returned reference inherits the exclusive access represented by buf.