pub enum TpmuPublicId {
KeyedHash(Tpm2bDigest),
SymCipher(Tpm2bSymKey),
Rsa(Tpm2bPublicKeyRsa),
Ecc(TpmsEccPoint),
Null,
}Variants
Implementations
Sourceimpl TpmuPublicId
impl TpmuPublicId
Sourcepub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuPublicIdView<'a>, &'a [u8])>where
Tpm2bDigest: TpmField<'a>,
Tpm2bSymKey: TpmField<'a>,
Tpm2bPublicKeyRsa: TpmField<'a>,
TpmsEccPoint: TpmField<'a>,
pub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuPublicIdView<'a>, &'a [u8])>where
Tpm2bDigest: TpmField<'a>,
Tpm2bSymKey: TpmField<'a>,
Tpm2bPublicKeyRsa: TpmField<'a>,
TpmsEccPoint: TpmField<'a>,
Casts a tag-selected union payload into a borrowed view.
Errors
Returns Err(TpmError) when tag does not select a valid variant or
buf does not start with a valid selected payload.