pub enum TpmuSensitiveComposite {
Rsa(Tpm2bPrivateKeyRsa),
Ecc(Tpm2bEccParameter),
Bits(Tpm2bSensitiveData),
Sym(Tpm2bSymKey),
}Variants
Implementations
Sourceimpl TpmuSensitiveComposite
impl TpmuSensitiveComposite
Sourcepub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuSensitiveCompositeView<'a>, &'a [u8])>where
Tpm2bPrivateKeyRsa: TpmField<'a>,
Tpm2bEccParameter: TpmField<'a>,
Tpm2bSensitiveData: TpmField<'a>,
Tpm2bSymKey: TpmField<'a>,
pub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuSensitiveCompositeView<'a>, &'a [u8])>where
Tpm2bPrivateKeyRsa: TpmField<'a>,
Tpm2bEccParameter: TpmField<'a>,
Tpm2bSensitiveData: TpmField<'a>,
Tpm2bSymKey: TpmField<'a>,
Casts a tag-selected union payload into a borrowed view.
Errors
Returns Err(TpmError) when tag does not select a valid variant or
buf does not start with a valid selected payload.