pub enum TpmuSignature {
Rsassa(TpmsSignatureRsa),
Rsapss(TpmsSignatureRsa),
Ecdsa(TpmsSignatureEcc),
Ecdaa(TpmsSignatureEcc),
Sm2(TpmsSignatureEcc),
Ecschnorr(TpmsSignatureEcc),
Hmac(TpmtHa),
Null,
}Variants
Rsassa(TpmsSignatureRsa)
Rsapss(TpmsSignatureRsa)
Ecdsa(TpmsSignatureEcc)
Ecdaa(TpmsSignatureEcc)
Sm2(TpmsSignatureEcc)
Ecschnorr(TpmsSignatureEcc)
Hmac(TpmtHa)
Null
Implementations
Sourceimpl TpmuSignature
impl TpmuSignature
Sourcepub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuSignatureView<'a>, &'a [u8])>
pub fn cast_tagged<'a>( tag: TpmAlgId, buf: &'a [u8], ) -> TpmResult<(TpmuSignatureView<'a>, &'a [u8])>
Casts a tag-selected union payload into a borrowed view.
Errors
Returns Err(TpmError) when tag does not select a valid variant or
buf does not start with a valid selected payload.