pub enum TpmuSymKeyBits {
Aes(TpmUint16),
Sm4(TpmUint16),
Camellia(TpmUint16),
Xor(TpmAlgId),
Null,
}Variants
Implementations
Sourceimpl TpmuSymKeyBits
impl TpmuSymKeyBits
Sourcepub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuSymKeyBitsView<'a>, &'a [u8])>
pub fn cast_tagged<'a>( tag: TpmAlgId, buf: &'a [u8], ) -> TpmResult<(TpmuSymKeyBitsView<'a>, &'a [u8])>
Casts a tag-selected union payload into a borrowed view.
Errors
Returns Err(TpmError) when tag does not select a valid variant or
buf does not start with a valid selected payload.