pub struct TpmsEmptyWire(/* private fields */);Implementations
Sourceimpl TpmsEmptyWire
impl TpmsEmptyWire
Sourcepub fn cast(buf: &[u8]) -> TpmResult<&Self>
pub fn cast(buf: &[u8]) -> TpmResult<&Self>
Casts bytes into a typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
Casts the first typed wire structure from buf and returns the remainder.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
Casts bytes into a typed wire structure view without validation.
Safety
The caller must ensure buf is exactly one valid wire structure.