pub struct TpmsSensitiveCreateWire(/* private fields */);Implementations
Sourceimpl TpmsSensitiveCreateWire
impl TpmsSensitiveCreateWire
Sourcepub fn cast(buf: &[u8]) -> TpmResult<&Self>
pub fn cast(buf: &[u8]) -> TpmResult<&Self>
Casts bytes into a typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
Casts the first typed wire structure from buf and returns the remainder.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
Casts bytes into a typed wire structure view without validation.
Safety
The caller must ensure buf is exactly one valid wire structure.
Sourcepub fn validate(buf: &[u8]) -> TpmResult<()>
pub fn validate(buf: &[u8]) -> TpmResult<()>
Validates an exact typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>
pub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>
Validates a typed wire structure prefix.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub fn user_auth(&self) -> TpmResult<&Tpm2bAuth>
pub fn user_auth(&self) -> TpmResult<&Tpm2bAuth>
Returns a borrowed field view.
Errors
Returns Err(TpmError) when preceding fields or this field are malformed.
Sourcepub fn data(&self) -> TpmResult<&Tpm2bSensitiveData>where
Tpm2bAuth: for<'a> TpmField<'a>,
Tpm2bSensitiveData: for<'a> TpmField<'a, View = &'a Tpm2bSensitiveData>,
pub fn data(&self) -> TpmResult<&Tpm2bSensitiveData>where
Tpm2bAuth: for<'a> TpmField<'a>,
Tpm2bSensitiveData: for<'a> TpmField<'a, View = &'a Tpm2bSensitiveData>,
Returns a borrowed field view.
Errors
Returns Err(TpmError) when preceding fields or this field are malformed.