pub struct TpmsSymcipherParmsWire(/* private fields */);Implementations
Sourceimpl TpmsSymcipherParmsWire
impl TpmsSymcipherParmsWire
Sourcepub fn cast(buf: &[u8]) -> TpmResult<&Self>where
TpmtSymDefObject: for<'a> TpmField<'a>,
pub fn cast(buf: &[u8]) -> TpmResult<&Self>where
TpmtSymDefObject: for<'a> TpmField<'a>,
Casts bytes into a typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>where
TpmtSymDefObject: for<'a> TpmField<'a>,
pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>where
TpmtSymDefObject: for<'a> TpmField<'a>,
Casts the first typed wire structure from buf and returns the remainder.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
Casts bytes into a typed wire structure view without validation.
Safety
The caller must ensure buf is exactly one valid wire structure.
Sourcepub fn validate(buf: &[u8]) -> TpmResult<()>where
TpmtSymDefObject: for<'a> TpmField<'a>,
pub fn validate(buf: &[u8]) -> TpmResult<()>where
TpmtSymDefObject: for<'a> TpmField<'a>,
Validates an exact typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>where
TpmtSymDefObject: for<'a> TpmField<'a>,
pub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>where
TpmtSymDefObject: for<'a> TpmField<'a>,
Validates a typed wire structure prefix.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub fn sym(&self) -> TpmResult<&TpmtSymDefObject>
pub fn sym(&self) -> TpmResult<&TpmtSymDefObject>
Returns a borrowed field view.
Errors
Returns Err(TpmError) when preceding fields or this field are malformed.