pub struct TpmsTimeInfoWire(/* private fields */);Implementations
Sourceimpl TpmsTimeInfoWire
impl TpmsTimeInfoWire
Sourcepub fn cast(buf: &[u8]) -> TpmResult<&Self>
pub fn cast(buf: &[u8]) -> TpmResult<&Self>
Casts bytes into a typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>
Casts the first typed wire structure from buf and returns the remainder.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self
Casts bytes into a typed wire structure view without validation.
Safety
The caller must ensure buf is exactly one valid wire structure.
Sourcepub fn validate(buf: &[u8]) -> TpmResult<()>
pub fn validate(buf: &[u8]) -> TpmResult<()>
Validates an exact typed wire structure view.
Errors
Returns Err(TpmError) when buf is not exactly one valid wire
structure.
Sourcepub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>
pub fn validate_prefix(buf: &[u8]) -> TpmResult<usize>
Validates a typed wire structure prefix.
Errors
Returns Err(TpmError) when buf does not start with a valid wire
structure.
Sourcepub fn time(&self) -> TpmResult<&TpmUint64>
pub fn time(&self) -> TpmResult<&TpmUint64>
Returns a borrowed field view.
Errors
Returns Err(TpmError) when preceding fields or this field are malformed.
Sourcepub fn clock_info(&self) -> TpmResult<&TpmsClockInfo>where
TpmUint64: for<'a> TpmField<'a>,
TpmsClockInfo: for<'a> TpmField<'a, View = &'a TpmsClockInfo>,
pub fn clock_info(&self) -> TpmResult<&TpmsClockInfo>where
TpmUint64: for<'a> TpmField<'a>,
TpmsClockInfo: for<'a> TpmField<'a, View = &'a TpmsClockInfo>,
Returns a borrowed field view.
Errors
Returns Err(TpmError) when preceding fields or this field are malformed.