TpmCommandView

Enum TpmCommandView 

pub enum TpmCommandView<'a> {
Show 125 variants NvUndefineSpaceSpecial(&'a TpmCommand), EvictControl(&'a TpmCommand), HierarchyControl(&'a TpmCommand), NvUndefineSpace(&'a TpmCommand), ChangeEps(&'a TpmCommand), ChangePps(&'a TpmCommand), Clear(&'a TpmCommand), ClearControl(&'a TpmCommand), ClockSet(&'a TpmCommand), HierarchyChangeAuth(&'a TpmCommand), NvDefineSpace(&'a TpmCommand), PcrAllocate(&'a TpmCommand), PcrSetAuthPolicy(&'a TpmCommand), PpCommands(&'a TpmCommand), SetPrimaryPolicy(&'a TpmCommand), FieldUpgradeStart(&'a TpmCommand), ClockRateAdjust(&'a TpmCommand), CreatePrimary(&'a TpmCommand), NvGlobalWriteLock(&'a TpmCommand), GetCommandAuditDigest(&'a TpmCommand), NvIncrement(&'a TpmCommand), NvSetBits(&'a TpmCommand), NvExtend(&'a TpmCommand), NvWrite(&'a TpmCommand), NvWriteLock(&'a TpmCommand), DictionaryAttackLockReset(&'a TpmCommand), DictionaryAttackParameters(&'a TpmCommand), NvChangeAuth(&'a TpmCommand), PcrEvent(&'a TpmCommand), PcrReset(&'a TpmCommand), SequenceComplete(&'a TpmCommand), SetAlgorithmSet(&'a TpmCommand), SetCommandCodeAuditStatus(&'a TpmCommand), FieldUpgradeData(&'a TpmCommand), IncrementalSelfTest(&'a TpmCommand), SelfTest(&'a TpmCommand), Startup(&'a TpmCommand), Shutdown(&'a TpmCommand), StirRandom(&'a TpmCommand), ActivateCredential(&'a TpmCommand), Certify(&'a TpmCommand), PolicyNv(&'a TpmCommand), CertifyCreation(&'a TpmCommand), Duplicate(&'a TpmCommand), GetTime(&'a TpmCommand), GetSessionAuditDigest(&'a TpmCommand), NvRead(&'a TpmCommand), NvReadLock(&'a TpmCommand), ObjectChangeAuth(&'a TpmCommand), PolicySecret(&'a TpmCommand), Rewrap(&'a TpmCommand), Create(&'a TpmCommand), EcdhZGen(&'a TpmCommand), Hmac(&'a TpmCommand), Import(&'a TpmCommand), Load(&'a TpmCommand), Quote(&'a TpmCommand), RsaDecrypt(&'a TpmCommand), HmacStart(&'a TpmCommand), SequenceUpdate(&'a TpmCommand), Sign(&'a TpmCommand), Unseal(&'a TpmCommand), PolicySigned(&'a TpmCommand), ContextLoad(&'a TpmCommand), ContextSave(&'a TpmCommand), EcdhKeyGen(&'a TpmCommand), EncryptDecrypt(&'a TpmCommand), FlushContext(&'a TpmCommand), LoadExternal(&'a TpmCommand), MakeCredential(&'a TpmCommand), NvReadPublic(&'a TpmCommand), PolicyAuthorize(&'a TpmCommand), PolicyAuthValue(&'a TpmCommand), PolicyCommandCode(&'a TpmCommand), PolicyCounterTimer(&'a TpmCommand), PolicyCpHash(&'a TpmCommand), PolicyLocality(&'a TpmCommand), PolicyNameHash(&'a TpmCommand), PolicyOr(&'a TpmCommand), PolicyTicket(&'a TpmCommand), ReadPublic(&'a TpmCommand), RsaEncrypt(&'a TpmCommand), StartAuthSession(&'a TpmCommand), VerifySignature(&'a TpmCommand), EccParameters(&'a TpmCommand), FirmwareRead(&'a TpmCommand), GetCapability(&'a TpmCommand), GetRandom(&'a TpmCommand), GetTestResult(&'a TpmCommand), Hash(&'a TpmCommand), PcrRead(&'a TpmCommand), PolicyPcr(&'a TpmCommand), PolicyRestart(&'a TpmCommand), ReadClock(&'a TpmCommand), PcrExtend(&'a TpmCommand), PcrSetAuthValue(&'a TpmCommand), NvCertify(&'a TpmCommand), EventSequenceComplete(&'a TpmCommand), HashSequenceStart(&'a TpmCommand), PolicyPhysicalPresence(&'a TpmCommand), PolicyDuplicationSelect(&'a TpmCommand), PolicyGetDigest(&'a TpmCommand), TestParms(&'a TpmCommand), Commit(&'a TpmCommand), PolicyPassword(&'a TpmCommand), ZGen2Phase(&'a TpmCommand), EcEphemeral(&'a TpmCommand), PolicyNvWritten(&'a TpmCommand), PolicyTemplate(&'a TpmCommand), CreateLoaded(&'a TpmCommand), PolicyAuthorizeNv(&'a TpmCommand), EncryptDecrypt2(&'a TpmCommand), AcGetCapability(&'a TpmCommand), AcSend(&'a TpmCommand), PolicyAcSendSelect(&'a TpmCommand), ActSetTimeout(&'a TpmCommand), EccEncrypt(&'a TpmCommand), EccDecrypt(&'a TpmCommand), PolicyCapability(&'a TpmCommand), PolicyParameters(&'a TpmCommand), NvDefineSpace2(&'a TpmCommand), NvReadPublic2(&'a TpmCommand), ReadOnlyControl(&'a TpmCommand), PolicyTransportSpdm(&'a TpmCommand), VendorTcgTest(&'a TpmCommand),
}
A borrowed TPM command frame selected by command code.

Variants



NvUndefineSpaceSpecial(&'a TpmCommand)



EvictControl(&'a TpmCommand)



HierarchyControl(&'a TpmCommand)



NvUndefineSpace(&'a TpmCommand)



ChangeEps(&'a TpmCommand)



ChangePps(&'a TpmCommand)



Clear(&'a TpmCommand)



ClearControl(&'a TpmCommand)



ClockSet(&'a TpmCommand)



HierarchyChangeAuth(&'a TpmCommand)



NvDefineSpace(&'a TpmCommand)



PcrAllocate(&'a TpmCommand)



PcrSetAuthPolicy(&'a TpmCommand)



PpCommands(&'a TpmCommand)



SetPrimaryPolicy(&'a TpmCommand)



FieldUpgradeStart(&'a TpmCommand)



ClockRateAdjust(&'a TpmCommand)



CreatePrimary(&'a TpmCommand)



NvGlobalWriteLock(&'a TpmCommand)



GetCommandAuditDigest(&'a TpmCommand)



NvIncrement(&'a TpmCommand)



NvSetBits(&'a TpmCommand)



NvExtend(&'a TpmCommand)



NvWrite(&'a TpmCommand)



NvWriteLock(&'a TpmCommand)



DictionaryAttackLockReset(&'a TpmCommand)



DictionaryAttackParameters(&'a TpmCommand)



NvChangeAuth(&'a TpmCommand)



PcrEvent(&'a TpmCommand)



PcrReset(&'a TpmCommand)



SequenceComplete(&'a TpmCommand)



SetAlgorithmSet(&'a TpmCommand)



SetCommandCodeAuditStatus(&'a TpmCommand)



FieldUpgradeData(&'a TpmCommand)



IncrementalSelfTest(&'a TpmCommand)



SelfTest(&'a TpmCommand)



Startup(&'a TpmCommand)



Shutdown(&'a TpmCommand)



StirRandom(&'a TpmCommand)



ActivateCredential(&'a TpmCommand)



Certify(&'a TpmCommand)



PolicyNv(&'a TpmCommand)



CertifyCreation(&'a TpmCommand)



Duplicate(&'a TpmCommand)



GetTime(&'a TpmCommand)



GetSessionAuditDigest(&'a TpmCommand)



NvRead(&'a TpmCommand)



NvReadLock(&'a TpmCommand)



ObjectChangeAuth(&'a TpmCommand)



PolicySecret(&'a TpmCommand)



Rewrap(&'a TpmCommand)



Create(&'a TpmCommand)



EcdhZGen(&'a TpmCommand)



Hmac(&'a TpmCommand)



Import(&'a TpmCommand)



Load(&'a TpmCommand)



Quote(&'a TpmCommand)



RsaDecrypt(&'a TpmCommand)



HmacStart(&'a TpmCommand)



SequenceUpdate(&'a TpmCommand)



Sign(&'a TpmCommand)



Unseal(&'a TpmCommand)



PolicySigned(&'a TpmCommand)



ContextLoad(&'a TpmCommand)



ContextSave(&'a TpmCommand)



EcdhKeyGen(&'a TpmCommand)



EncryptDecrypt(&'a TpmCommand)



FlushContext(&'a TpmCommand)



LoadExternal(&'a TpmCommand)



MakeCredential(&'a TpmCommand)



NvReadPublic(&'a TpmCommand)



PolicyAuthorize(&'a TpmCommand)



PolicyAuthValue(&'a TpmCommand)



PolicyCommandCode(&'a TpmCommand)



PolicyCounterTimer(&'a TpmCommand)



PolicyCpHash(&'a TpmCommand)



PolicyLocality(&'a TpmCommand)



PolicyNameHash(&'a TpmCommand)



PolicyOr(&'a TpmCommand)



PolicyTicket(&'a TpmCommand)



ReadPublic(&'a TpmCommand)



RsaEncrypt(&'a TpmCommand)



StartAuthSession(&'a TpmCommand)



VerifySignature(&'a TpmCommand)



EccParameters(&'a TpmCommand)



FirmwareRead(&'a TpmCommand)



GetCapability(&'a TpmCommand)



GetRandom(&'a TpmCommand)



GetTestResult(&'a TpmCommand)



Hash(&'a TpmCommand)



PcrRead(&'a TpmCommand)



PolicyPcr(&'a TpmCommand)



PolicyRestart(&'a TpmCommand)



ReadClock(&'a TpmCommand)



PcrExtend(&'a TpmCommand)



PcrSetAuthValue(&'a TpmCommand)



NvCertify(&'a TpmCommand)



EventSequenceComplete(&'a TpmCommand)



HashSequenceStart(&'a TpmCommand)



PolicyPhysicalPresence(&'a TpmCommand)



PolicyDuplicationSelect(&'a TpmCommand)



PolicyGetDigest(&'a TpmCommand)



TestParms(&'a TpmCommand)



Commit(&'a TpmCommand)



PolicyPassword(&'a TpmCommand)



ZGen2Phase(&'a TpmCommand)



EcEphemeral(&'a TpmCommand)



PolicyNvWritten(&'a TpmCommand)



PolicyTemplate(&'a TpmCommand)



CreateLoaded(&'a TpmCommand)



PolicyAuthorizeNv(&'a TpmCommand)



EncryptDecrypt2(&'a TpmCommand)



AcGetCapability(&'a TpmCommand)



AcSend(&'a TpmCommand)



PolicyAcSendSelect(&'a TpmCommand)



ActSetTimeout(&'a TpmCommand)



EccEncrypt(&'a TpmCommand)



EccDecrypt(&'a TpmCommand)



PolicyCapability(&'a TpmCommand)



PolicyParameters(&'a TpmCommand)



NvDefineSpace2(&'a TpmCommand)



NvReadPublic2(&'a TpmCommand)



ReadOnlyControl(&'a TpmCommand)



PolicyTransportSpdm(&'a TpmCommand)



VendorTcgTest(&'a TpmCommand)

Implementations

Source

impl<'a> TpmCommandView<'a>

pub fn cast_frame(buf: &'a [u8]) -> TpmResult<Self>

Casts bytes into a borrowed command dispatch value.

Errors

Returns Err(TpmError) when the command frame is malformed or its command code has no dispatch entry.

pub fn cast(command: &'a TpmCommand) -> TpmResult<Self>

Selects a borrowed command dispatch value from a command wire view.

Errors

Returns Err(TpmError) when the command frame is malformed or its command code has no dispatch entry.

pub fn command(&self) -> &'a TpmCommand

Returns the selected command frame.

pub fn cc(&self) -> TpmCc

Returns the selected command code.