pub struct TpmAcGetCapabilityResponse {
pub handles: [TpmHandle; 0],
pub more_data: TpmiYesNo,
pub capabilities_data: TpmlAcCapabilities,
}Fields
handles: [TpmHandle; 0]more_data: TpmiYesNocapabilities_data: TpmlAcCapabilitiesImplementations
Sourceimpl TpmAcGetCapabilityResponse
impl TpmAcGetCapabilityResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.