pub struct TpmCertifyCreationCommand {
pub handles: [TpmHandle; 2],
pub qualifying_data: Tpm2bData,
pub creation_hash: Tpm2bDigest,
pub in_scheme: TpmtSignature,
pub creation_ticket: TpmtTkCreation,
}Fields
handles: [TpmHandle; 2]qualifying_data: Tpm2bDatacreation_hash: Tpm2bDigestin_scheme: TpmtSignaturecreation_ticket: TpmtTkCreationImplementations
Sourceimpl TpmCertifyCreationCommand
impl TpmCertifyCreationCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.