pub struct TpmCommitCommand {
pub handles: [TpmHandle; 1],
pub p1: Tpm2bEccPoint,
pub s2: Tpm2bSensitiveData,
pub y2: Tpm2bEccParameter,
}Fields
handles: [TpmHandle; 1]p1: Tpm2bEccPoints2: Tpm2bSensitiveDatay2: Tpm2bEccParameterImplementations
Sourceimpl TpmCommitCommand
impl TpmCommitCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.