pub struct TpmCommitResponse {
pub handles: [TpmHandle; 0],
pub k: Tpm2bEccPoint,
pub l: Tpm2bEccPoint,
pub e: Tpm2bEccPoint,
pub counter: TpmUint16,
}Fields
handles: [TpmHandle; 0]k: Tpm2bEccPointl: Tpm2bEccPointe: Tpm2bEccPointcounter: TpmUint16Implementations
Sourceimpl TpmCommitResponse
impl TpmCommitResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.