pub struct TpmCreateLoadedResponse {
pub handles: [TpmHandle; 1],
pub out_private: Tpm2bPrivate,
pub out_public: Tpm2bPublic,
pub name: Tpm2bName,
}Fields
handles: [TpmHandle; 1]out_private: Tpm2bPrivateout_public: Tpm2bPublicname: Tpm2bNameImplementations
Sourceimpl TpmCreateLoadedResponse
impl TpmCreateLoadedResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.