pub struct TpmCreatePrimaryResponse {
pub handles: [TpmHandle; 1],
pub out_public: Tpm2bPublic,
pub creation_data: Tpm2bCreationData,
pub creation_hash: Tpm2bDigest,
pub creation_ticket: TpmtTkCreation,
pub name: Tpm2bName,
}Fields
handles: [TpmHandle; 1]out_public: Tpm2bPubliccreation_data: Tpm2bCreationDatacreation_hash: Tpm2bDigestcreation_ticket: TpmtTkCreationname: Tpm2bNameImplementations
Sourceimpl TpmCreatePrimaryResponse
impl TpmCreatePrimaryResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.