pub struct TpmCreateResponse {
pub handles: [TpmHandle; 0],
pub out_private: Tpm2bPrivate,
pub out_public: Tpm2bPublic,
pub creation_data: Tpm2bCreationData,
pub creation_hash: Tpm2bDigest,
pub creation_ticket: TpmtTkCreation,
}Fields
handles: [TpmHandle; 0]out_private: Tpm2bPrivateout_public: Tpm2bPubliccreation_data: Tpm2bCreationDatacreation_hash: Tpm2bDigestcreation_ticket: TpmtTkCreationImplementations
Sourceimpl TpmCreateResponse
impl TpmCreateResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.