pub struct TpmDictionaryAttackParametersCommand {
pub handles: [TpmHandle; 1],
pub new_max_tries: TpmUint32,
pub new_recovery_time: TpmUint32,
pub lockout_recovery: TpmUint32,
}Fields
handles: [TpmHandle; 1]new_max_tries: TpmUint32new_recovery_time: TpmUint32lockout_recovery: TpmUint32Implementations
Sourceimpl TpmDictionaryAttackParametersCommand
impl TpmDictionaryAttackParametersCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.