pub struct TpmEccDecryptCommand {
pub handles: [TpmHandle; 1],
pub c1: Tpm2bEccPoint,
pub c2: Tpm2bMaxBuffer,
pub c3: Tpm2bDigest,
pub in_scheme: TpmtKdfScheme,
}Fields
handles: [TpmHandle; 1]c1: Tpm2bEccPointc2: Tpm2bMaxBufferc3: Tpm2bDigestin_scheme: TpmtKdfSchemeImplementations
Sourceimpl TpmEccDecryptCommand
impl TpmEccDecryptCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.