pub struct TpmEcdhKeyGenResponse {
pub handles: [TpmHandle; 0],
pub z_point: Tpm2bEccPoint,
pub pub_point: Tpm2bEccPoint,
}Fields
handles: [TpmHandle; 0]z_point: Tpm2bEccPointpub_point: Tpm2bEccPointImplementations
Sourceimpl TpmEcdhKeyGenResponse
impl TpmEcdhKeyGenResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.