pub struct TpmEncryptDecrypt2Command {
pub handles: [TpmHandle; 1],
pub in_data: Tpm2bMaxBuffer,
pub decrypt: TpmiYesNo,
pub mode: TpmAlgId,
pub iv_in: Tpm2bIv,
}Fields
handles: [TpmHandle; 1]in_data: Tpm2bMaxBufferdecrypt: TpmiYesNomode: TpmAlgIdiv_in: Tpm2bIvImplementations
Sourceimpl TpmEncryptDecrypt2Command
impl TpmEncryptDecrypt2Command
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.