pub struct TpmEncryptDecryptCommand {
pub handles: [TpmHandle; 1],
pub decrypt: TpmiYesNo,
pub mode: TpmiAlgCipherMode,
pub iv_in: Tpm2bIv,
pub in_data: Tpm2bMaxBuffer,
}Fields
handles: [TpmHandle; 1]decrypt: TpmiYesNomode: TpmiAlgCipherModeiv_in: Tpm2bIvin_data: Tpm2bMaxBufferImplementations
Sourceimpl TpmEncryptDecryptCommand
impl TpmEncryptDecryptCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.