pub struct TpmFieldUpgradeStartCommand {
pub handles: [TpmHandle; 2],
pub fu_digest: Tpm2bDigest,
pub manifest_signature: TpmtSignature,
}Fields
handles: [TpmHandle; 2]fu_digest: Tpm2bDigestmanifest_signature: TpmtSignatureImplementations
Sourceimpl TpmFieldUpgradeStartCommand
impl TpmFieldUpgradeStartCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.