pub struct TpmGetCapabilityCommand {
pub handles: [TpmHandle; 0],
pub cap: TpmCap,
pub property: TpmUint32,
pub property_count: TpmUint32,
}Fields
handles: [TpmHandle; 0]cap: TpmCapproperty: TpmUint32property_count: TpmUint32Implementations
Sourceimpl TpmGetCapabilityCommand
impl TpmGetCapabilityCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.