pub struct TpmGetCommandAuditDigestResponse {
pub handles: [TpmHandle; 0],
pub audit_info: Tpm2bAttest,
pub signature: TpmtSignature,
}Fields
handles: [TpmHandle; 0]audit_info: Tpm2bAttestsignature: TpmtSignatureImplementations
Sourceimpl TpmGetCommandAuditDigestResponse
impl TpmGetCommandAuditDigestResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.