pub struct TpmGetSessionAuditDigestCommand {
pub handles: [TpmHandle; 3],
pub qualifying_data: Tpm2bData,
pub in_scheme: TpmtSignature,
}Fields
handles: [TpmHandle; 3]qualifying_data: Tpm2bDatain_scheme: TpmtSignatureImplementations
Sourceimpl TpmGetSessionAuditDigestCommand
impl TpmGetSessionAuditDigestCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.