pub struct TpmGetTestResultResponse {
pub handles: [TpmHandle; 0],
pub out_data: Tpm2bMaxBuffer,
pub test_result: TpmRc,
}Fields
handles: [TpmHandle; 0]out_data: Tpm2bMaxBuffertest_result: TpmRcImplementations
Sourceimpl TpmGetTestResultResponse
impl TpmGetTestResultResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.