pub struct TpmGetTimeResponse {
pub handles: [TpmHandle; 0],
pub time_info: Tpm2bAttest,
pub signature: TpmtSignature,
}Fields
handles: [TpmHandle; 0]time_info: Tpm2bAttestsignature: TpmtSignatureImplementations
Sourceimpl TpmGetTimeResponse
impl TpmGetTimeResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.