pub struct TpmImportCommand {
pub handles: [TpmHandle; 1],
pub encryption_key: Tpm2bData,
pub object_public: Tpm2bPublic,
pub duplicate: Tpm2bPrivate,
pub in_sym_seed: Tpm2bEncryptedSecret,
pub symmetric_alg: TpmtSymDef,
}Fields
handles: [TpmHandle; 1]encryption_key: Tpm2bDataobject_public: Tpm2bPublicduplicate: Tpm2bPrivatein_sym_seed: Tpm2bEncryptedSecretsymmetric_alg: TpmtSymDefImplementations
Sourceimpl TpmImportCommand
impl TpmImportCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.