pub struct TpmNvCertifyCommand {
pub handles: [TpmHandle; 3],
pub qualifying_data: Tpm2bData,
pub in_scheme: TpmtSignature,
pub size: TpmUint16,
pub offset: TpmUint16,
}Fields
handles: [TpmHandle; 3]qualifying_data: Tpm2bDatain_scheme: TpmtSignaturesize: TpmUint16offset: TpmUint16Implementations
Sourceimpl TpmNvCertifyCommand
impl TpmNvCertifyCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.