pub struct TpmNvDefineSpaceCommand {
pub handles: [TpmHandle; 1],
pub auth: Tpm2bAuth,
pub public_info: Tpm2bNvPublic,
}Fields
handles: [TpmHandle; 1]auth: Tpm2bAuthpublic_info: Tpm2bNvPublicImplementations
Sourceimpl TpmNvDefineSpaceCommand
impl TpmNvDefineSpaceCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.