pub struct TpmPcrSetAuthPolicyCommand {
pub handles: [TpmHandle; 1],
pub auth_policy: Tpm2bDigest,
pub hash_alg: TpmAlgId,
pub pcr_num: TpmRh,
}Fields
handles: [TpmHandle; 1]auth_policy: Tpm2bDigesthash_alg: TpmAlgIdpcr_num: TpmRhImplementations
Sourceimpl TpmPcrSetAuthPolicyCommand
impl TpmPcrSetAuthPolicyCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.