pub struct TpmPolicyAuthorizeCommand {
pub handles: [TpmHandle; 1],
pub approved_policy: Tpm2bDigest,
pub policy_ref: Tpm2bNonce,
pub key_sign: Tpm2bName,
pub check_ticket: TpmtTkVerified,
}Fields
handles: [TpmHandle; 1]approved_policy: Tpm2bDigestpolicy_ref: Tpm2bNoncekey_sign: Tpm2bNamecheck_ticket: TpmtTkVerifiedImplementations
Sourceimpl TpmPolicyAuthorizeCommand
impl TpmPolicyAuthorizeCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.