pub struct TpmPolicyCapabilityCommand {
pub handles: [TpmHandle; 1],
pub capability: TpmCap,
pub property: TpmUint32,
pub op: TpmEo,
pub operand_b: Tpm2bMaxBuffer,
}Fields
handles: [TpmHandle; 1]capability: TpmCapproperty: TpmUint32op: TpmEooperand_b: Tpm2bMaxBufferImplementations
Sourceimpl TpmPolicyCapabilityCommand
impl TpmPolicyCapabilityCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.