pub struct TpmPolicyNameHashCommand {
pub handles: [TpmHandle; 1],
pub name_hash: Tpm2bDigest,
}Fields
handles: [TpmHandle; 1]name_hash: Tpm2bDigestImplementations
Sourceimpl TpmPolicyNameHashCommand
impl TpmPolicyNameHashCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.