pub struct TpmPolicyNvCommand {
pub handles: [TpmHandle; 3],
pub operand_b: Tpm2bMaxBuffer,
pub offset: TpmUint16,
pub operation: TpmEo,
}Fields
handles: [TpmHandle; 3]operand_b: Tpm2bMaxBufferoffset: TpmUint16operation: TpmEoImplementations
Sourceimpl TpmPolicyNvCommand
impl TpmPolicyNvCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.