pub struct TpmPolicySignedCommand {
pub handles: [TpmHandle; 2],
pub nonce_tpm: Tpm2bNonce,
pub cp_hash_a: Tpm2bDigest,
pub policy_ref: Tpm2bNonce,
pub expiration: TpmInt32,
pub auth: TpmtSignature,
}Fields
handles: [TpmHandle; 2]nonce_tpm: Tpm2bNoncecp_hash_a: Tpm2bDigestpolicy_ref: Tpm2bNonceexpiration: TpmInt32auth: TpmtSignatureImplementations
Sourceimpl TpmPolicySignedCommand
impl TpmPolicySignedCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.