pub struct TpmPolicyTransportSpdmCommand {
pub handles: [TpmHandle; 1],
pub req_key_name: Tpm2bName,
pub tpm_key_name: Tpm2bName,
}Fields
handles: [TpmHandle; 1]req_key_name: Tpm2bNametpm_key_name: Tpm2bNameImplementations
Sourceimpl TpmPolicyTransportSpdmCommand
impl TpmPolicyTransportSpdmCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.