pub struct TpmReadPublicResponse {
pub handles: [TpmHandle; 0],
pub out_public: Tpm2bPublic,
pub name: Tpm2bName,
pub qualified_name: Tpm2bName,
}Fields
handles: [TpmHandle; 0]out_public: Tpm2bPublicname: Tpm2bNamequalified_name: Tpm2bNameImplementations
Sourceimpl TpmReadPublicResponse
impl TpmReadPublicResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.