pub struct TpmSelfTestCommand {
pub handles: [TpmHandle; 0],
pub full_test: TpmiYesNo,
}Fields
handles: [TpmHandle; 0]full_test: TpmiYesNoImplementations
Sourceimpl TpmSelfTestCommand
impl TpmSelfTestCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.