pub struct TpmSequenceCompleteCommand {
pub handles: [TpmHandle; 1],
pub buffer: Tpm2bMaxBuffer,
pub hierarchy: TpmRh,
}Fields
handles: [TpmHandle; 1]buffer: Tpm2bMaxBufferhierarchy: TpmRhImplementations
Sourceimpl TpmSequenceCompleteCommand
impl TpmSequenceCompleteCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.