pub struct TpmSetCapabilityCommand {
pub handles: [TpmHandle; 1],
pub set_data: TpmsCapabilityData,
}Fields
handles: [TpmHandle; 1]set_data: TpmsCapabilityDataImplementations
Sourceimpl TpmSetCapabilityCommand
impl TpmSetCapabilityCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmError) when the frame is malformed or
has a different command code.