pub struct TpmStartAuthSessionCommand {
pub handles: [TpmHandle; 2],
pub nonce_caller: Tpm2bNonce,
pub encrypted_salt: Tpm2bEncryptedSecret,
pub session_type: TpmSe,
pub symmetric: TpmtSymDefObject,
pub auth_hash: TpmAlgId,
}Fields
handles: [TpmHandle; 2]nonce_caller: Tpm2bNonceencrypted_salt: Tpm2bEncryptedSecretsession_type: TpmSesymmetric: TpmtSymDefObjectauth_hash: TpmAlgIdImplementations
Sourceimpl TpmStartAuthSessionCommand
impl TpmStartAuthSessionCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.