pub struct TpmStartAuthSessionResponse {
pub handles: [TpmHandle; 1],
pub nonce_tpm: Tpm2bNonce,
}Fields
handles: [TpmHandle; 1]nonce_tpm: Tpm2bNonceImplementations
Sourceimpl TpmStartAuthSessionResponse
impl TpmStartAuthSessionResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmProtocolError) when the frame envelope is malformed.