pub struct TpmZGen2PhaseCommand {
pub handles: [TpmHandle; 1],
pub in_qsb: Tpm2bEccPoint,
pub in_qeb: Tpm2bEccPoint,
pub in_scheme: TpmiEccKeyExchange,
pub counter: TpmUint16,
}Fields
handles: [TpmHandle; 1]in_qsb: Tpm2bEccPointin_qeb: Tpm2bEccPointin_scheme: TpmiEccKeyExchangecounter: TpmUint16Implementations
Sourceimpl TpmZGen2PhaseCommand
impl TpmZGen2PhaseCommand
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmCommand>
Casts a command frame into a typed wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmCommand>
Casts a mutable command frame into a typed mutable wire view for this command.
Errors
Returns Err(TpmProtocolError) when the frame is malformed or
has a different command code.