pub struct TpmZGen2PhaseResponse {
pub handles: [TpmHandle; 0],
pub out_z1: Tpm2bEccPoint,
pub out_z2: Tpm2bEccPoint,
}Fields
handles: [TpmHandle; 0]out_z1: Tpm2bEccPointout_z2: Tpm2bEccPointImplementations
Sourceimpl TpmZGen2PhaseResponse
impl TpmZGen2PhaseResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.