TpmWireBytes

Struct TpmWireBytes 

pub struct TpmWireBytes<const N: usize>(/* private fields */);
A byte-backed TPM wire view with a fixed byte length.

Implementations

Source

impl<const N: usize> TpmWireBytes<N>

pub fn cast(buf: &[u8]) -> TpmResult<&Self>

Casts a byte slice into a fixed-size TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes. Returns TrailingData when buf is larger than N bytes.

pub fn validate(buf: &[u8]) -> TpmResult<()>

Validates an exact fixed-size TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes. Returns TrailingData when buf is larger than N bytes.

pub fn validate_prefix(buf: &[u8]) -> TpmResult<()>

Validates that buf starts with a fixed-size TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes.

pub fn cast_prefix(buf: &[u8]) -> TpmResult<(&Self, &[u8])>

Casts the first N bytes into a fixed-size TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes.

pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self

Casts a byte slice into a fixed-size TPM wire view without validation.

Safety

The caller must ensure that buf.len() == N. Callers must also ensure any higher-level protocol invariants required by later typed accessors have been validated.

pub fn cast_mut(buf: &mut [u8]) -> TpmResult<&mut Self>

Casts a mutable byte slice into a fixed-size mutable TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes. Returns TrailingData when buf is larger than N bytes.

pub fn cast_prefix_mut(buf: &mut [u8]) -> TpmResult<(&mut Self, &mut [u8])>

Casts the first N mutable bytes into a fixed-size TPM wire view.

Errors

Returns UnexpectedEnd when buf is smaller than N bytes.

pub unsafe fn cast_mut_unchecked(buf: &mut [u8]) -> &mut Self

Casts a mutable byte slice into a fixed-size mutable TPM wire view without validation.

Safety

The caller must ensure that buf.len() == N. Callers must also ensure any higher-level protocol invariants required by later typed accessors have been validated. The returned reference inherits the exclusive access represented by buf.

pub const fn as_bytes(&self) -> &[u8; N]

Returns the backing bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8; N]

Returns the mutable backing bytes.

pub const fn len(&self) -> usize

Returns the number of backing bytes.

pub const fn is_empty(&self) -> bool

Returns true when the backing byte array is empty.