pub enum TpmuSymMode {
Aes(TpmAlgId),
Sm4(TpmAlgId),
Camellia(TpmAlgId),
Xor(TpmAlgId),
Null,
}Variants
Implementations
Sourceimpl TpmuSymMode
impl TpmuSymMode
Sourcepub fn cast_tagged<'a>(
tag: TpmAlgId,
buf: &'a [u8],
) -> TpmResult<(TpmuSymModeView<'a>, &'a [u8])>
pub fn cast_tagged<'a>( tag: TpmAlgId, buf: &'a [u8], ) -> TpmResult<(TpmuSymModeView<'a>, &'a [u8])>
Casts a tag-selected union payload into a borrowed view.
Errors
Returns Err(TpmError) when tag does not select a valid variant or
buf does not start with a valid selected payload.