pub enum TpmProtocolError {
BufferOverflow,
IntegerTooLarge,
InvalidBoolean,
InvalidCc,
InvalidMagicNumber,
InvalidTag,
TooManyBytes,
TooManyItems,
TrailingData,
UnexpectedEnd,
VariantNotAvailable,
}Expand description
TPM frame marshaling and unmarshaling error type containing variants for all the possible error conditions.
Variants
BufferOverflow
Trying to marshal more bytes than buffer has space. This is unexpected situation, and should be considered possible bug in the crate itself.
IntegerTooLarge
Integer overflow while converting to an integer of a different size.
InvalidBoolean
Boolean value was expected but the value is neither 0 nor 1.
InvalidCc
Non-existent command code encountered.
InvalidMagicNumber
An TpmAttest instance contains an invalid
magic value.
InvalidTag
Tag is neither Sessions nor
NoSessions.
TooManyBytes
Buffer contains more bytes than allowed by the TCG specifications.
TooManyItems
List contains more items than allowed by the TCG specifications.
TrailingData
Trailing data left after unmarshaling.
UnexpectedEnd
Run out of bytes while unmarshaling.
VariantNotAvailable
The variant accessed is not available.