pub struct TpmIncrementalSelfTestResponse {
pub handles: [TpmHandle; 0],
pub to_do_list: TpmlAlg,
}Fields
handles: [TpmHandle; 0]to_do_list: TpmlAlgImplementations
Sourceimpl TpmIncrementalSelfTestResponse
impl TpmIncrementalSelfTestResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.