pub struct TpmMakeCredentialResponse {
pub handles: [TpmHandle; 0],
pub credential_blob: Tpm2bIdObject,
pub secret: Tpm2bEncryptedSecret,
}Fields
handles: [TpmHandle; 0]credential_blob: Tpm2bIdObjectsecret: Tpm2bEncryptedSecretImplementations
Sourceimpl TpmMakeCredentialResponse
impl TpmMakeCredentialResponse
Sourcepub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
pub fn cast_frame(buf: &[u8]) -> TpmResult<&TpmResponse>
Casts a response frame into a typed wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.
Sourcepub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
pub fn cast_frame_mut(buf: &mut [u8]) -> TpmResult<&mut TpmResponse>
Casts a mutable response frame into a typed mutable wire view for this response.
Errors
Returns Err(TpmError) when the frame envelope is malformed.