pub struct TpmErrorValue {
pub offset: usize,
pub value: u64,
pub needed: usize,
pub available: usize,
pub limit: usize,
pub actual: usize,
}Expand description
Additional structured data for a TPM protocol error.
Fields
offset: usizeByte offset from the start of the parsed buffer.
value: u64Raw value associated with the error.
needed: usizeRequired byte or item count.
available: usizeAvailable byte or item count.
limit: usizeMaximum allowed byte or item count.
actual: usizeActual byte or item count.
Implementations
Sourceimpl TpmErrorValue
impl TpmErrorValue
Sourcepub const fn value_usize(self, value: usize) -> Self
pub const fn value_usize(self, value: usize) -> Self
Sets a raw usize value associated with the error.
Sourcepub const fn actual(self, actual: usize) -> Self
pub const fn actual(self, actual: usize) -> Self
Sets an actual count without a corresponding limit.
Sourcepub const fn size(self, needed: usize, available: usize) -> Self
pub const fn size(self, needed: usize, available: usize) -> Self
Sets the required and available counts.
Sourcepub const fn limit(self, limit: usize, actual: usize) -> Self
pub const fn limit(self, limit: usize, actual: usize) -> Self
Sets the maximum allowed and actual counts.