TpmErrorValue

Struct TpmErrorValue 

pub struct TpmErrorValue {
    pub offset: usize,
    pub value: u64,
    pub needed: usize,
    pub available: usize,
    pub limit: usize,
    pub actual: usize,
}
Additional structured data for a TPM protocol error.

Fields

offset: usize

Byte offset from the start of the parsed buffer.

value: u64

Raw value associated with the error.

needed: usize

Required byte or item count.

available: usize

Available byte or item count.

limit: usize

Maximum allowed byte or item count.

actual: usize

Actual byte or item count.

Implementations

Source

impl TpmErrorValue

pub const fn new(offset: usize) -> Self

Creates empty error data at a byte offset.

pub const fn value(self, value: u64) -> Self

Sets the raw value associated with the error.

pub const fn value_usize(self, value: usize) -> Self

Sets a raw usize value associated with the error.

pub const fn actual(self, actual: usize) -> Self

Sets an actual count without a corresponding limit.

pub const fn size(self, needed: usize, available: usize) -> Self

Sets the required and available counts.

pub const fn limit(self, limit: usize, actual: usize) -> Self

Sets the maximum allowed and actual counts.

pub fn at(base: &[u8], cursor: &[u8]) -> Self

Creates error data from a cursor slice inside a base slice.

pub fn offset(base: &[u8], cursor: &[u8]) -> usize

Returns the byte offset of a cursor slice inside a base slice.