TpmWire

Struct TpmWire 

pub struct TpmWire(/* private fields */);
A byte-backed TPM wire view.

Implementations

Source

impl TpmWire

pub fn cast(buf: &[u8]) -> &Self

Casts a byte slice into a TPM wire view.

pub fn cast_prefix(buf: &[u8]) -> (&Self, &[u8])

Casts a byte slice into a TPM wire view and returns no remainder.

pub fn cast_mut(buf: &mut [u8]) -> &mut Self

Casts a mutable byte slice into a mutable TPM wire view.

pub fn cast_prefix_mut(buf: &mut [u8]) -> (&mut Self, &mut [u8])

Casts a mutable byte slice into a mutable TPM wire view and returns no remainder.

pub const fn as_bytes(&self) -> &[u8]

Returns the backing bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

Returns the mutable backing bytes.

pub const fn len(&self) -> usize

Returns the number of backing bytes.

pub const fn is_empty(&self) -> bool

Returns true when the backing byte slice is empty.

Source

impl TpmWire

pub unsafe fn cast_unchecked(buf: &[u8]) -> &Self

Casts a byte slice into this wire view without validation.

Safety

The caller must ensure buf satisfies every invariant required by the checked constructors for this view.

pub unsafe fn cast_mut_unchecked(buf: &mut [u8]) -> &mut Self

Casts a mutable byte slice into this wire view without validation.

Safety

The caller must ensure buf satisfies every invariant required by the checked constructors for this view. The returned reference inherits the exclusive access represented by buf.